@@ -199,6 +199,9 @@ def standardized_raw(
     if isinstance(metrics, str):
         raise TypeError("metrics should be a list of strings")
 
+    if isinstance(company_identifiers, str):
+        raise TypeError("company_identifiers should be a list of strings")
+
     if all_history and any(
         [year, period, start_period, start_year, end_period, end_year]
     ):
@@ -323,6 +326,9 @@ def point_in_time(
 ) -> "pd.DataFrame":
     """Point-in-Time Data
 
+    .. deprecated:: 6.0.1
+        Use :func:`standardized` with the `point_in_time=True` argument.
+
     Standardized data with a timestamp when it was published by Calcbench.
 
 
@@ -397,6 +403,7 @@ def point_in_time(
 
     """
 
+    warnings.warn("Prefer standardized with point_in_time=True.", DeprecationWarning)
     data = standardized_raw(
         company_identifiers=company_identifiers,
         all_face=all_face,
@@ -640,6 +647,7 @@ def standardized(
         filing_id=filing_id,
         all_metrics=not metrics,
         use_fiscal_period=True,
+        include_preliminary=point_in_time,
     )
 
     data = _build_data_frame(data)
